========
Credits
========

website template
=================

As the saying goes, "imitation is the sincerest form of flattery," and
all credit for this website's template goes to the authors of the
scipy documentation template.
